powered by
Uses a discrete global grid system to convert between GEO and PLANE (see vignette for details)
dgGEO_to_PLANE(dggs, in_lon_deg, in_lat_deg)
A dggs object from dgconstruct()
Vector of longitude, in degrees
Vector of latitude, in degrees
Returns a dggs object which can be passed to other dggridR functions
# NOT RUN { library(dggridR) dggs <- dgconstruct(res=20) dgGEO_to_PLANE(dggs, in_lon_deg, in_lat_deg) # } # NOT RUN { # }
Run the code above in your browser using DataLab