Learn R Programming

dggridR (version 2.0.4)

dgPROJTRI_to_PLANE: Convert from PROJTRI to PLANE

Description

Uses a discrete global grid system to convert between PROJTRI and PLANE (see vignette for details)

Usage

dgPROJTRI_to_PLANE(dggs, in_tnum, in_tx, in_ty)

Arguments

dggs

A dggs object from dgconstruct()

in_tnum

Vector of triangle numbers

in_tx

Vector of triangle x values

in_ty

Vector of triangle y values

Value

Returns a dggs object which can be passed to other dggridR functions

Examples

Run this code
# NOT RUN {
library(dggridR)
dggs <- dgconstruct(res=20)

dgPROJTRI_to_PLANE(dggs, in_tnum, in_tx, in_ty)
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab