powered by
Uses a discrete global grid system to convert between Q2DD and PLANE (see vignette for details)
dgQ2DD_to_PLANE(dggs, in_quad, in_qx, in_qy)
A dggs object from dgconstruct()
Vector of quad numbers
Vector of quadrant x values
Vector of quadrant y values
Returns a dggs object which can be passed to other dggridR functions
# NOT RUN { library(dggridR) dggs <- dgconstruct(res=20) dgQ2DD_to_PLANE(dggs, in_quad, in_qx, in_qy) # } # NOT RUN { # }
Run the code above in your browser using DataLab