powered by
Uses a discrete global grid system to convert between SEQNUM and PLANE (see vignette for details)
dgSEQNUM_to_PLANE(dggs, in_seqnum)
A dggs object from dgconstruct()
Globally unique number identifying the surface polygon
Returns a dggs object which can be passed to other dggridR functions
# NOT RUN { library(dggridR) dggs <- dgconstruct(res=20) dgSEQNUM_to_PLANE(dggs, in_seqnum) # } # NOT RUN { # }
Run the code above in your browser using DataLab