powered by
Determine an appropriate grid resolution based on a desired spacing between the center of adjacent cells.
dg_closest_res_to_spacing( dggs, spacing, round = "nearest", show_info = TRUE, metric = TRUE )
A dggs object from dgconstruct()
The desired spacing between the center of adjacent cells
What direction to search in. Must be nearest, up, or down.
Print the area, spacing, and CLS of the chosen resolution.
Whether input and output should be in metric (TRUE) or imperial (FALSE)
A number representing the grid resolution
# NOT RUN { library(dggridR) dggs <- dgconstruct(res=20) res <- dg_closest_res_to_spacing(dggs,1) dggs <- dgsetres(dggs,res) # }
Run the code above in your browser using DataLab