Learn R Programming

dggridR (version 2.0.4)

dg_shpfname_south_africa: National border of South Africa

Description

This variable points to a shapefile containing the national border of South Africa

Usage

dg_shpfname_south_africa()

Arguments

Value

A filename of a shapefile containing the national border of South Africa