powered by
Uses a discrete global grid system to convert between PROJTRI and PLANE (see vignette for details)
dgPROJTRI_to_PLANE(dggs, in_tnum, in_tx, in_ty)
A dggs object from dgconstruct()
Vector of triangle numbers
Vector of triangle x values
Vector of triangle y values
Returns a dggs object which can be passed to other dggridR functions
# NOT RUN { library(dggridR) dggs <- dgconstruct(res=20) dgPROJTRI_to_PLANE(dggs, in_tnum, in_tx, in_ty) # } # NOT RUN { # }
Run the code above in your browser using DataLab