Learn R Programming

dggridR (version 2.0.4)

dgearthgrid: Return the coordinates constituting the boundary of cells for the entire Earth

Description

Note: If you have a high-resolution grid this may take a loooooong time to execute.

Usage

dgearthgrid(dggs, frame = TRUE, wrapcells = TRUE, savegrid = NA)

Arguments

dggs

A dggs object from dgconstruct()

frame

If TRUE, return a data frame suitable for ggplot plotting. If FALSE, return an OGR poly object

wrapcells

Cells which cross -180/180 degrees can present difficulties for plotting. Setting this TRUE will result in cells with components in both hemispheres to be mapped entirely to positive degrees (the Eastern hemisphere). As a result, such cells will have components in the range [180,360). Only used when frame=TRUE.

savegrid

If savegrid is set to a file path, then a shapefile containing the grid is written to that path and the filename is returned. No other manipulations are done. Default: NA (do not save grid, return it)

Value

Returns a data frame or OGR poly object, as specified by frame. If !is.na(savegrid), returns a filename.

Examples

Run this code
# NOT RUN {
library(dggridR)
dggs         <- dgconstruct(res=20)
res          <- dg_closest_res_to_spacing(dggs,spacing=1000,round='down',metric=FALSE)
dggs         <- dgsetres(dggs,res)
gridfilename <- dgearthgrid(dggs,savegrid="temp.shp") #Save directly to a file
# }

Run the code above in your browser using DataLab