Learn R Programming

dggridR (version 2.0.4)

dggetres: Get table of grid resolution information

Description

Gets a grid's resolution and cell property info as a data frame.

Usage

dggetres(dggs)

Arguments

dggs

A dggs object from dgconstruct()

Value

A data frame containing the resolution levels, number of cells, area of those cells, intercell spacing, and characteristic length scale of the cells. All values are in kilometres.

Examples

Run this code
# NOT RUN {
library(dggridR)
dggs <- dgconstruct(res=20)
dggetres(dggs)
# }

Run the code above in your browser using DataLab